@@ -48,6 +48,7 @@ Note:
 import click
 
 from dragonfly.cli.validate import validate
+from dragonfly.cli.create import create
 from dragonfly.cli.translate import translate
 from dragonfly.cli.edit import edit
 
@@ -65,6 +66,7 @@ def viz():
 
 
 main.add_command(validate)
+main.add_command(create)
 main.add_command(translate)
 main.add_command(edit)
 
